==> easy_deployer-0.1.6.tar.gz: easy_deployer-0.1.6/setup.py <==
from setuptools import setup, find_packages

with open("README.md") as f:
    long_desc = f.read()
setup(
    name="easy_deployer",
    version="0.1.6",
    description="A package to simplify and quickly deploy your project/app/folders to the supported platforms",
    long_description=long_desc,
    long_description_content_type='text/markdown',
    author="Mohamed-Amine Benali",
    author_email="benali.medamine2002@gmail.com",
    url="https://github.com/medamine980/easy-deployer",
    packages=find_packages(exclude=["easy_deployer.dist", "easy_deployer.ignore"]),
    license="MIT",
    keywords=["python", "github", "github-deployer", "heroku", 
    "heroku-deployer", "deploy", "easy", "easy-deployer", "simple", "simple-deployer"],
    install_required=["pipreqs"],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.11'
    ],
    entry_points = {
        'console_scripts': [
            'easy-deployer = easy_deployer.main:main',
            'easy-deployer-github = easy_deployer.github:main',
            'easy-deployer-heroku = easy_deployer.heroku:main'
        ]
    }
    # console_scripts={
    #     "easy-deployer-github": "easy_deployer.github:main",
    #     "easy-deployer-heroku": "easy_deployer.heroku:main",
    #     "easy-deployer": "easy_deployer.main:main"
    # }
)

==> easy_deployer-0.1.7.tar.gz: easy_deployer-0.1.7/setup.py <==
from setuptools import setup, find_packages

with open("README.md") as f:
    long_desc = f.read()
setup(
    name="easy_deployer",
    version="0.1.7",
    description="A package to simplify and quickly deploy your project/app/folders to the supported platforms.",
    long_description=long_desc,
    long_description_content_type='text/markdown',
    author="Mohamed-Amine Benali",
    author_email="benali.medamine2002@gmail.com",
    url="https://github.com/medamine980/easy-deployer",
    packages=find_packages(exclude=["easy_deployer.dist", "easy_deployer.ignore"]),
    license="MIT",
    keywords=["python", "github", "github-deployer", "heroku", 
    "heroku-deployer", "deploy", "easy", "easy-deployer", "simple", "simple-deployer"],
    install_required=["pipreqs"],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.11'
    ],
    entry_points = {
        'console_scripts': [
            'easy-deployer = easy_deployer.main:main',
            'easy-deployer-github = easy_deployer.github:main',
            'easy-deployer-heroku = easy_deployer.heroku:main'
        ]
    }
    # console_scripts={
    #     "easy-deployer-github": "easy_deployer.github:main",
    #     "easy-deployer-heroku": "easy_deployer.heroku:main",
    #     "easy-deployer": "easy_deployer.main:main"
    # }
)
